@@ -649,16 +649,16 @@ class DeviceFs():
     def exists(self, *dn):
         return self.fs.exists(self.pathjoin(*dn))
 
-    def read(self, *fn):
-        return self.fs.read(self.pathjoin(*fn))
+    def read(self, *fn, encoding="UTF-8", binary=False):
+        return self.fs.read(self.pathjoin(*fn), encoding=encoding, binary=binary)
 
     def realpath(self, *fn):
         return self.fs.realpath(self.pathjoin(*fn))
 
-    def write(self, *args):
+    def write(self, *args, encoding="UTF-8", binary=False):
         fn = args[:-1]
         data = args[-1]
-        self.fs.write(self.pathjoin(*fn), data)
+        self.fs.write(self.pathjoin(*fn), data, encoding=encoding, binary=binary)
 
     def listdir(self, *dn, **kw):
         fullpath = kw.get("fullpath", False)
