@@ -14,19 +14,19 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 import sys
-from calculate.lib.utils.files import grepFile, getRunCommands
-from calculate.lib.utils.tools import cached, traverse
+from .files import grepFile, getRunCommands
+from .tools import cached, traverse
 from os import path
 import os
 from collections import defaultdict
 from fnmatch import fnmatch, filter as fnfilter
 
 _ = lambda x: x
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
-class X86(object):
+class X86():
     def __init__(self, rootdn):
         self.rootdn = rootdn
         self.usrlib = path.join(rootdn, "usr/lib")
@@ -37,7 +37,7 @@ class X86(object):
         self.pythonsite = path.join(rootdn, "usr/lib/python3.9/site-packages")
         self.libopengl = path.join(rootdn, "usr/lib/opengl")
 
-class Amd64(object):
+class Amd64():
     def __init__(self, rootdn):
         self.rootdn = rootdn
         self.usrlib = path.join(rootdn, "usr/lib64")
@@ -58,7 +58,7 @@ def SystemPath(rootdn):
         return X86(rootdn)
 
 
-class SystemType(object):
+class SystemType():
     """
     Тип контейнера текущей системы
     """
@@ -109,7 +109,7 @@ class SystemType(object):
     def detect(cls):
         return cls.detect_container() or cls.detect_vm()
 
-class FUser(object):
+class FUser():
     def __init__(self, ffilter=None):
         self.ffilter = ffilter
         self.ref = defaultdict(list)
